summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorPaul Eggert <eggert@cs.ucla.edu>2016-11-06 00:33:43 -0700
committerPaul Eggert <eggert@cs.ucla.edu>2016-11-06 00:42:03 -0700
commitdc152c54f4e44f5f2040883b03f71ff6aa66c893 (patch)
tree7b4f0336a1f03e7a53d980000a42568b10907409 /src
parent84c53436ab25b6c8f76c133e59b34e533ea33cc7 (diff)
downloademacs-dc152c54f4e44f5f2040883b03f71ff6aa66c893.tar.gz
Modernize usage of 'macOS' in doc and comments
Apple changed the spelling of its operating system again, to "macOS", effective with macOS 10.12 Sierra (2016-09-20). Change Emacs documentation and comments to match this. Stick with older OS spellings ("OS X", "Mac OS X") when talking about older releases where the older names are more correct.
Diffstat (limited to 'src')
-rw-r--r--src/coding.c2
-rw-r--r--src/conf_post.h2
-rw-r--r--src/emacs.c2
-rw-r--r--src/frame.c2
-rw-r--r--src/gtkutil.c2
-rw-r--r--src/macfont.h2
-rw-r--r--src/macfont.m6
-rw-r--r--src/nsfns.m8
-rw-r--r--src/nsfont.m4
-rw-r--r--src/nsimage.m4
-rw-r--r--src/nsmenu.m14
-rw-r--r--src/nsselect.m4
-rw-r--r--src/nsterm.m56
-rw-r--r--src/sysdep.c2
-rw-r--r--src/unexmacosx.c12
15 files changed, 61 insertions, 61 deletions
diff --git a/src/coding.c b/src/coding.c
index 9f709bea24c..3e4af722e4c 100644
--- a/src/coding.c
+++ b/src/coding.c
@@ -122,7 +122,7 @@ END-OF-LINE FORMAT
How text end-of-line is encoded depends on operating system. For
instance, Unix's format is just one byte of LF (line-feed) code,
whereas DOS's format is two-byte sequence of `carriage-return' and
- `line-feed' codes. MacOS's format is usually one byte of
+ `line-feed' codes. Classic Mac OS's format is usually one byte of
`carriage-return'.
Since text character encoding and end-of-line encoding are
diff --git a/src/conf_post.h b/src/conf_post.h
index f83965bf8b1..d8070fad8e7 100644
--- a/src/conf_post.h
+++ b/src/conf_post.h
@@ -192,7 +192,7 @@ You lose; /* Emacs for DOS must be compiled with DJGPP */
#endif
#endif /* MSDOS */
-/* Mac OS X / GNUstep need a bit more pure memory. Of the existing knobs,
+/* macOS / GNUstep need a bit more pure memory. Of the existing knobs,
SYSTEM_PURESIZE_EXTRA seems like the least likely to cause problems. */
#ifdef HAVE_NS
#if defined NS_IMPL_GNUSTEP
diff --git a/src/emacs.c b/src/emacs.c
index f8d5dfa3c6e..ce30ae741b2 100644
--- a/src/emacs.c
+++ b/src/emacs.c
@@ -2412,7 +2412,7 @@ Special values:
`gnu' compiled for a GNU Hurd system.
`gnu/linux' compiled for a GNU/Linux system.
`gnu/kfreebsd' compiled for a GNU system with a FreeBSD kernel.
- `darwin' compiled for Darwin (GNU-Darwin, Mac OS X, ...).
+ `darwin' compiled for Darwin (GNU-Darwin, macOS, ...).
`ms-dos' compiled as an MS-DOS application.
`windows-nt' compiled as a native W32 application.
`cygwin' compiled using the Cygwin library.
diff --git a/src/frame.c b/src/frame.c
index cfa5f7d5027..854f72e64b4 100644
--- a/src/frame.c
+++ b/src/frame.c
@@ -5088,7 +5088,7 @@ Setting this variable does not affect existing frames, only new ones. */);
doc: /* Default position of vertical scroll bars on this window-system. */);
#ifdef HAVE_WINDOW_SYSTEM
#if defined (HAVE_NTGUI) || defined (NS_IMPL_COCOA) || (defined (USE_GTK) && defined (USE_TOOLKIT_SCROLL_BARS))
- /* MS-Windows, Mac OS X, and GTK have scroll bars on the right by
+ /* MS-Windows, macOS, and GTK have scroll bars on the right by
default. */
Vdefault_frame_scroll_bars = Qright;
#else
diff --git a/src/gtkutil.c b/src/gtkutil.c
index 0f256c563dc..e323216bb79 100644
--- a/src/gtkutil.c
+++ b/src/gtkutil.c
@@ -2370,7 +2370,7 @@ make_widget_for_menu_item (const char *utf8_label, const char *utf8_key)
in the group. On exit, *GROUP contains the radio item group.
Unfortunately, keys don't line up as nicely as in Motif,
- but the MacOS X version doesn't either, so I guess that is OK. */
+ but the macOS version doesn't either, so I guess that is OK. */
static GtkWidget *
make_menu_item (const char *utf8_label,
diff --git a/src/macfont.h b/src/macfont.h
index 6630fb526b7..8f734527a46 100644
--- a/src/macfont.h
+++ b/src/macfont.h
@@ -1,4 +1,4 @@
-/* Interface definition for Mac OSX Core text font backend.
+/* Interface definition for macOS Core text font backend.
Copyright (C) 2009-2016 Free Software Foundation, Inc.
This file is part of GNU Emacs.
diff --git a/src/macfont.m b/src/macfont.m
index 04456283fa1..ed7c1e3bd7a 100644
--- a/src/macfont.m
+++ b/src/macfont.m
@@ -1,4 +1,4 @@
-/* Font driver on Mac OSX Core text.
+/* Font driver on macOS Core text.
Copyright (C) 2009-2016 Free Software Foundation, Inc.
This file is part of GNU Emacs.
@@ -1005,7 +1005,7 @@ macfont_set_family_cache (Lisp_Object symbol, CFStringRef string)
and those start with ".". NULL means the cache has been invalidated.
Otherwise, the value is CFArray of CFStrings and the elements are
sorted in the canonical order (CTFontManagerCompareFontFamilyNames on
-OS X 10.6 and later). */
+Mac OS X 10.6 and later). */
static CFArrayRef macfont_available_families_cache = NULL;
@@ -4042,7 +4042,7 @@ mac_register_font_driver (struct frame *f)
void
syms_of_macfont (void)
{
- /* Core Text, for Mac OS X. */
+ /* Core Text, for macOS. */
DEFSYM (Qmac_ct, "mac-ct");
macfont_driver.type = Qmac_ct;
register_font_driver (&macfont_driver, NULL);
diff --git a/src/nsfont.m b/src/nsfont.m
index 92e7d1154bf..4f95ee3a1a8 100644
--- a/src/nsfont.m
+++ b/src/nsfont.m
@@ -1,4 +1,4 @@
-/* Font back-end driver for the NeXT/Open/GNUstep and MacOSX window system.
+/* Font back-end driver for the NeXT/Open/GNUstep and macOS window system.
See font.h
Copyright (C) 2006-2016 Free Software Foundation, Inc.
@@ -500,7 +500,7 @@ static NSSet
{
NSCharacterSet *fset = [[fontMgr fontWithFamily: family
traits: 0 weight: 5 size: 12.0] coveredCharacterSet];
- /* Some fonts on OS X, maybe many on GNUstep, return nil. */
+ /* Some fonts on macOS, maybe many on GNUstep, return nil. */
if (fset == nil)
fset = [NSCharacterSet characterSetWithRange:
NSMakeRange (0, 127)];
diff --git a/src/sysdep.c b/src/sysdep.c
index 460166d119e..674e76db7a0 100644
--- a/src/sysdep.c
+++ b/src/sysdep.c
@@ -2337,7 +2337,7 @@ posix_close (int fd, int flag)
closed, and retrying the close could inadvertently close a file
descriptor allocated by some other thread. In other systems
(e.g., HP/UX) FD is not closed. And in still other systems
- (e.g., OS X, Solaris), maybe FD is closed, maybe not, and in a
+ (e.g., macOS, Solaris), maybe FD is closed, maybe not, and in a
multithreaded program there can be no way to tell.
So, in this case, pretend that the close succeeded. This works
diff --git a/src/nsfns.m b/src/nsfns.m
index 9bc6c1d3418..82bb84a147a 100644
--- a/src/nsfns.m
+++ b/src/nsfns.m
@@ -1,4 +1,4 @@
/* Functions for the NeXT/Open/GNUstep and MacOSX window system.
Copyright (C) 1989, 1992-1994, 2005-2006, 2008-2016 Free Software
Foundation, Inc.
@@ -22,7 +22,7 @@ along with GNU Emacs. If not, see <http://www.gnu.org/licenses/>. */
Originally by Carl Edman
Updated by Christian Limpach (chris@nice.ch)
OpenStep/Rhapsody port by Scott Bender (sbender@harmony-ds.com)
-MacOSX/Aqua port by Christophe de Dinechin (descubes@earthlink.net)
+macOS/Aqua port by Christophe de Dinechin (descubes@earthlink.net)
GNUstep port and post-20 update by Adrian Robert (arobert@cogsci.ucsd.edu)
*/
@@ -942,7 +942,7 @@ static void
x_icon (struct frame *f, Lisp_Object parms)
/* --------------------------------------------------------------------------
Strangely-named function to set icon position parameters in frame.
- This is irrelevant under OS X, but might be needed under GNUstep,
+ This is irrelevant under macOS, but might be needed under GNUstep,
depending on the window manager used. Note, this is not a standard
frame parameter-setter; it is called directly from x-create-frame.
-------------------------------------------------------------------------- */
@@ -2060,7 +2060,7 @@ DEFUN ("ns-list-services", Fns_list_services, Sns_list_services, 0, 0, 0,
[svcs setAutoenablesItems: NO];
#ifdef NS_IMPL_COCOA
- [svcs update]; /* on OS X, converts from '/' structure */
+ [svcs update]; /* on macOS, converts from '/' structure */
#endif
ret = interpret_services_menu (svcs, Qnil, ret);
@@ -1,4 +1,4 @@
-/* Functions for the NeXT/Open/GNUstep and MacOSX window system.
+/* Functions for the NeXT/Open/GNUstep and macOS window system.
Copyright (C) 1989, 1992-1994, 2005-2006, 2008-2016 Free Software
Foundation, Inc.
diff --git a/src/nsimage.m b/src/nsimage.m
index 5b2534b9007..66aecd4289d 100644
--- a/src/nsimage.m
+++ b/src/nsimage.m
@@ -1,4 +1,4 @@
/* Image support for the NeXT/Open/GNUstep and MacOSX window system.
Copyright (C) 1989, 1992-1994, 2005-2006, 2008-2016 Free Software
Foundation, Inc.
@@ -21,7 +21,7 @@ along with GNU Emacs. If not, see <http://www.gnu.org/licenses/>. */
Originally by Carl Edman
Updated by Christian Limpach (chris@nice.ch)
OpenStep/Rhapsody port by Scott Bender (sbender@harmony-ds.com)
-MacOSX/Aqua port by Christophe de Dinechin (descubes@earthlink.net)
+macOS/Aqua port by Christophe de Dinechin (descubes@earthlink.net)
GNUstep port and post-20 update by Adrian Robert (arobert@cogsci.ucsd.edu)
*/
@@ -1,4 +1,4 @@
-/* Image support for the NeXT/Open/GNUstep and MacOSX window system.
+/* Image support for the NeXT/Open/GNUstep and macOS window system.
Copyright (C) 1989, 1992-1994, 2005-2006, 2008-2016 Free Software
Foundation, Inc.
diff --git a/src/nsmenu.m b/src/nsmenu.m
index 7d340e8ec83..f73c184dce7 100644
--- a/src/nsmenu.m
+++ b/src/nsmenu.m
@@ -1,4 +1,4 @@
/* NeXT/Open/GNUstep and MacOSX Cocoa menu and toolbar module.
Copyright (C) 2007-2016 Free Software Foundation, Inc.
This file is part of GNU Emacs.
@@ -93,7 +93,7 @@ popup_activated (void)
/* --------------------------------------------------------------------------
Update menubar. Three cases:
1) ! deep_p, submenu = nil: Fresh switch onto a frame -- either set up
- just top-level menu strings (OS X), or goto case (2) (GNUstep).
+ just top-level menu strings (macOS), or goto case (2) (GNUstep).
2) deep_p, submenu = nil: Recompute all submenus.
3) deep_p, submenu = non-nil: Update contents of a single submenu.
-------------------------------------------------------------------------- */
@@ -584,7 +584,7 @@ x_activate_menubar (struct frame *f)
return;
/*fprintf (stderr, "Updating menu '%s'\n", [[self title] UTF8String]); NSLog (@"%@\n", event); */
#ifdef NS_IMPL_GNUSTEP
/* Don't know how to do this for anything other than OSX >= 10.5
This is wrong, as it might run Lisp code in the event loop. */
ns_update_menubar (frame, true, self);
#endif
@@ -645,7 +645,7 @@ x_activate_menubar (struct frame *f)
keyEq = [self parseKeyEquiv: wv->key];
#ifdef NS_IMPL_COCOA
/* OS X just ignores modifier strings longer than one character */
if (keyEquivModMask == 0)
title = [title stringByAppendingFormat: @" (%@)", keyEq];
#endif
@@ -1057,9 +1057,9 @@ update_frame_tool_bar (struct frame *f)
/* Check if this is a separator. */
if (EQ (TOOLPROP (TOOL_BAR_ITEM_TYPE), Qt))
{
- /* Skip separators. Newer OSX don't show them, and on GNUstep they
- are wide as a button, thus overflowing the toolbar most of
- the time. */
+ /* Skip separators. Newer macOS don't show them, and on
+ GNUstep they are wide as a button, thus overflowing the
+ toolbar most of the time. */
continue;
}
@@ -1,4 +1,4 @@
-/* NeXT/Open/GNUstep and MacOSX Cocoa menu and toolbar module.
+/* NeXT/Open/GNUstep and macOS Cocoa menu and toolbar module.
Copyright (C) 2007-2016 Free Software Foundation, Inc.
This file is part of GNU Emacs.
@@ -584,7 +584,7 @@ x_activate_menubar (struct frame *f)
/*fprintf (stderr, "Updating menu '%s'\n", [[self title] UTF8String]); NSLog (@"%@\n", event); */
#ifdef NS_IMPL_GNUSTEP
- /* Don't know how to do this for anything other than OSX >= 10.5
+ /* Don't know how to do this for anything other than Mac OS X 10.5 and later.
This is wrong, as it might run Lisp code in the event loop. */
ns_update_menubar (frame, true, self);
@@ -645,7 +645,7 @@ x_activate_menubar (struct frame *f)
keyEq = [self parseKeyEquiv: wv->key];
#ifdef NS_IMPL_COCOA
- /* OS X just ignores modifier strings longer than one character */
+ /* macOS just ignores modifier strings longer than one character */
if (keyEquivModMask == 0)
title = [title stringByAppendingFormat: @" (%@)", keyEq];
diff --git a/src/nsselect.m b/src/nsselect.m
index eba23932e65..b7c9148ee05 100644
--- a/src/nsselect.m
+++ b/src/nsselect.m
@@ -1,4 +1,4 @@
/* NeXT/Open/GNUstep / MacOSX Cocoa selection processing for emacs.
Copyright (C) 1993-1994, 2005-2006, 2008-2016 Free Software
Foundation, Inc.
@@ -21,7 +21,7 @@ along with GNU Emacs. If not, see <http://www.gnu.org/licenses/>. */
Originally by Carl Edman
Updated by Christian Limpach (chris@nice.ch)
OpenStep/Rhapsody port by Scott Bender (sbender@harmony-ds.com)
-MacOSX/Aqua port by Christophe de Dinechin (descubes@earthlink.net)
+macOS/Aqua port by Christophe de Dinechin (descubes@earthlink.net)
GNUstep port and post-20 update by Adrian Robert (arobert@cogsci.ucsd.edu)
*/
@@ -1,4 +1,4 @@
-/* NeXT/Open/GNUstep / MacOSX Cocoa selection processing for emacs.
+/* NeXT/Open/GNUstep / macOS Cocoa selection processing for emacs.
Copyright (C) 1993-1994, 2005-2006, 2008-2016 Free Software
Foundation, Inc.
diff --git a/src/nsterm.m b/src/nsterm.m
index 4d9d10559ea..4f99a13c44e 100644
--- a/src/nsterm.m
+++ b/src/nsterm.m
@@ -1,4 +1,4 @@
/* NeXT/Open/GNUstep / MacOSX communication module. -*- coding: utf-8 -*-
Copyright (C) 1989, 1993-1994, 2005-2006, 2008-2016 Free Software
Foundation, Inc.
@@ -22,7 +22,7 @@ along with GNU Emacs. If not, see <http://www.gnu.org/licenses/>. */
Originally by Carl Edman
Updated by Christian Limpach (chris@nice.ch)
OpenStep/Rhapsody port by Scott Bender (sbender@harmony-ds.com)
-MacOSX/Aqua port by Christophe de Dinechin (descubes@earthlink.net)
+macOS/Aqua port by Christophe de Dinechin (descubes@earthlink.net)
GNUstep port and post-20 update by Adrian Robert (arobert@cogsci.ucsd.edu)
*/
@@ -250,7 +250,7 @@ static unsigned convert_ns_to_X_keysym[] =
0x1B, 0x1B /* escape */
};
/* On OS X picks up the default NSGlobalDomain AppleAntiAliasingThreshold,
the maximum font size to NOT antialias. On GNUstep there is currently
no way to control this behavior. */
float ns_antialias_threshold;
@@ -587,7 +587,7 @@ ns_load_path (void)
void
ns_init_locale (void)
/* OS X doesn't set any environment variables for the locale when run
from the GUI. Get the locale from the OS and set LANG. */
{
NSLocale *locale = [NSLocale currentLocale];
@@ -596,7 +596,7 @@ ns_init_locale (void)
@try
{
/* It seems OS X should probably use UTF-8 everywhere.
'localeIdentifier' does not specify the encoding, and I can't
find any way to get the OS to tell us which encoding to use,
so hard-code '.UTF-8'. */
@@ -718,7 +718,7 @@ ns_screen_margins (NSScreen *screen)
/* A screen margin between 1 and DOCK_IGNORE_LIMIT (inclusive) is
- assumed to contain a hidden dock. OS X currently use 4 pixels for
+ assumed to contain a hidden dock. macOS currently use 4 pixels for
this, however, to be future compatible, a larger value is used. */
#define DOCK_IGNORE_LIMIT 6
@@ -731,7 +731,7 @@ reserved for an hidden dock. */
struct EmacsMargins margins = ns_screen_margins(screen);
/* OS X (currently) reserved 4 pixels along the edge where a hidden
dock is located. Unfortunately, it's not possible to find the
location and information about if the dock is hidden. Instead,
it is assumed that if the margin of an edge is less than
@@ -748,7 +748,7 @@ reserved for an hidden dock. */
{
margins.top = 0;
}
/* Note: This doesn't occur in current versions of OS X, but
included for completeness and future compatibility. */
if (margins.bottom <= DOCK_IGNORE_LIMIT)
{
@@ -1027,7 +1027,7 @@ ns_update_begin (struct frame *f)
#ifdef NS_IMPL_COCOA
if ([view isFullscreen] && [view fsIsNative])
{
- // Fix reappearing tool bar in fullscreen for OSX 10.7
+ // Fix reappearing tool bar in fullscreen for Mac OS X 10.7
BOOL tbar_visible = FRAME_EXTERNAL_TOOL_BAR (f) ? YES : NO;
NSToolbar *toolbar = [FRAME_NS_VIEW (f) toolbar];
if (! tbar_visible != ! [toolbar isVisible])
@@ -1986,8 +1986,8 @@ ns_get_color (const char *name, NSColor **col)
}
else if ([nsname isEqualToString: @"ns_selection_fg_color"])
{
- /* NOTE: OSX applications normally don't set foreground selection, but
- text may be unreadable if we don't.
+ /* NOTE: macOS applications normally don't set foreground
+ selection, but text may be unreadable if we don't.
*/
if ((new = [NSColor selectedTextColor]) != nil)
{
@@ -3937,7 +3937,7 @@ ns_send_appdefined (int value)
#ifdef NS_IMPL_COCOA
if (! send_appdefined)
{
- /* OSX 10.10.1 swallows the AppDefined event we are sending ourselves
+ /* OS X 10.10.1 swallows the AppDefined event we are sending ourselves
in certain situations (rapid incoming events).
So check if we have one, if not add one. */
NSEvent *appev = [NSApp nextEventMatchingMask:NSApplicationDefinedMask
@@ -4816,7 +4816,7 @@ ns_term_init (Lisp_Object display_name)
[outerpool release];
outerpool = [[NSAutoreleasePool alloc] init];
/* count object allocs (About, click icon); on OS X use ObjectAlloc tool */
/*GSDebugAllocationActive (YES); */
block_input ();
@@ -4945,7 +4945,7 @@ ns_term_init (Lisp_Object display_name)
ns_app_name = [[NSProcessInfo processInfo] processName];
/* Set up OS X app menu */
NSTRACE_MSG ("Menu init");
@@ -5017,7 +5017,7 @@ ns_term_init (Lisp_Object display_name)
selector: @selector (trackingNotification:)
name: NSMenuDidEndTrackingNotification object: mainMenu];
}
-#endif /* MAC OS X menu setup */
+#endif /* macOS menu setup */
/* Register our external input/output types, used for determining
applicable services and also drag/drop eligibility. */
@@ -5245,7 +5245,7 @@ ns_term_shutdown (int sig)
#ifdef NS_IMPL_COCOA
/* If no dialog and none of our frames have focus and it is a move, skip it.
- It is a mouse move in an auxiliary menu, i.e. on the top right on OSX,
+ It is a mouse move in an auxiliary menu, i.e. on the top right on macOS,
such as Wifi, sound, date or similar.
This prevents "spooky" highlighting in the frame under the menu. */
if (type == NSMouseMoved && [NSApp modalWindow] == nil)
@@ -5784,7 +5784,7 @@ not_in_argv (NSString *arg)
NSTRACE ("[EmacsView keyDown:]");
/* Rhapsody and OS X give up and down events for the arrow keys */
if (ns_fake_keydown == YES)
ns_fake_keydown = NO;
else if ([theEvent type] != NSKeyDown)
@@ -6018,7 +6018,7 @@ not_in_argv (NSString *arg)
#ifdef NS_IMPL_COCOA
-/* Needed to pick up Ctrl-tab and possibly other events that OS X has
+/* Needed to pick up Ctrl-tab and possibly other events that Mac OS X
decided not to send key-down for.
See http://osdir.com/ml/editors.vim.mac/2007-10/msg00141.html
This only applies on Tiger and earlier.
@@ -7176,8 +7176,8 @@ not_in_argv (NSString *arg)
#if MAC_OS_X_VERSION_MAX_ALLOWED >= MAC_OS_X_VERSION_10_7
unsigned val = (unsigned)[NSApp presentationOptions];
// OSX 10.7 bug fix, the menu won't appear without this.
// val is non-zero on other OSX versions.
if (val == 0)
{
NSApplicationPresentationOptions options
@@ -7601,7 +7601,7 @@ not_in_argv (NSString *arg)
unblock_input ();
/*
- drawRect: may be called (at least in OS X 10.5) for invisible
+ drawRect: may be called (at least in Mac OS X 10.5) for invisible
views as well for some reason. Thus, do not infer visibility
here.
@@ -8123,7 +8123,7 @@ not_in_argv (NSString *arg)
[self setEnabled: YES];
/* Ensure auto resizing of scrollbars occurs within the emacs frame's view
- locked against the top and bottom edges, and right edge on OS X, where
+ locked against the top and bottom edges, and right edge on macOS, where
scrollers are on right. */
#ifdef NS_IMPL_GNUSTEP
[self setAutoresizingMask: NSViewMaxXMargin | NSViewHeightSizable];
@@ -8730,14 +8730,14 @@ allowing it to be used at a lower level for accented character entry.");
DEFVAR_LISP ("ns-auto-hide-menu-bar", ns_auto_hide_menu_bar,
doc: /* Non-nil means that the menu bar is hidden, but appears when the mouse is near.
-Only works on OSX 10.6 or later. */);
+Only works on Mac OS X 10.6 or later. */);
ns_auto_hide_menu_bar = Qnil;
DEFVAR_BOOL ("ns-use-native-fullscreen", ns_use_native_fullscreen,
- doc: /*Non-nil means to use native fullscreen on OSX >= 10.7.
+ doc: /*Non-nil means to use native fullscreen on Mac OS X 10.7 and later.
Nil means use fullscreen the old (< 10.7) way. The old way works better with
-multiple monitors, but lacks tool bar. This variable is ignored on OSX < 10.7.
-Default is t for OSX >= 10.7, nil otherwise. */);
+multiple monitors, but lacks tool bar. This variable is ignored on
+Mac OS X < 10.7. Default is t for 10.7 and later, nil otherwise. */);
#ifdef HAVE_NATIVE_FS
ns_use_native_fullscreen = YES;
#else
@@ -8752,9 +8752,9 @@ Default is nil. */);
ns_use_fullscreen_animation = NO;
DEFVAR_BOOL ("ns-use-srgb-colorspace", ns_use_srgb_colorspace,
- doc: /*Non-nil means to use sRGB colorspace on OSX >= 10.7.
+ doc: /*Non-nil means to use sRGB colorspace on Mac OS X 10.7 and later.
Note that this does not apply to images.
-This variable is ignored on OSX < 10.7 and GNUstep. */);
+This variable is ignored on Mac OS X < 10.7 and GNUstep. */);
ns_use_srgb_colorspace = YES;
/* TODO: move to common code */
@@ -1,4 +1,4 @@
-/* NeXT/Open/GNUstep / MacOSX communication module. -*- coding: utf-8 -*-
+/* NeXT/Open/GNUstep / macOS communication module. -*- coding: utf-8 -*-
Copyright (C) 1989, 1993-1994, 2005-2006, 2008-2016 Free Software
Foundation, Inc.
@@ -250,7 +250,7 @@ static unsigned convert_ns_to_X_keysym[] =
0x1B, 0x1B /* escape */
};
-/* On OS X picks up the default NSGlobalDomain AppleAntiAliasingThreshold,
+/* On macOS picks up the default NSGlobalDomain AppleAntiAliasingThreshold,
the maximum font size to NOT antialias. On GNUstep there is currently
no way to control this behavior. */
@@ -587,7 +587,7 @@ ns_load_path (void)
void
ns_init_locale (void)
-/* OS X doesn't set any environment variables for the locale when run
+/* macOS doesn't set any environment variables for the locale when run
from the GUI. Get the locale from the OS and set LANG. */
{
@@ -596,7 +596,7 @@ ns_init_locale (void)
{
- /* It seems OS X should probably use UTF-8 everywhere.
+ /* It seems macOS should probably use UTF-8 everywhere.
'localeIdentifier' does not specify the encoding, and I can't
find any way to get the OS to tell us which encoding to use,
@@ -731,7 +731,7 @@ reserved for an hidden dock. */
struct EmacsMargins margins = ns_screen_margins(screen);
- /* OS X (currently) reserved 4 pixels along the edge where a hidden
+ /* macOS (currently) reserved 4 pixels along the edge where a hidden
dock is located. Unfortunately, it's not possible to find the
location and information about if the dock is hidden. Instead,
@@ -748,7 +748,7 @@ reserved for an hidden dock. */
margins.top = 0;
}
- /* Note: This doesn't occur in current versions of OS X, but
+ /* Note: This doesn't occur in current versions of macOS, but
included for completeness and future compatibility. */
if (margins.bottom <= DOCK_IGNORE_LIMIT)
@@ -4816,7 +4816,7 @@ ns_term_init (Lisp_Object display_name)
[outerpool release];
outerpool = [[NSAutoreleasePool alloc] init];
- /* count object allocs (About, click icon); on OS X use ObjectAlloc tool */
+ /* count object allocs (About, click icon); on macOS use ObjectAlloc tool */
/*GSDebugAllocationActive (YES); */
block_input ();
@@ -4945,7 +4945,7 @@ ns_term_init (Lisp_Object display_name)
ns_app_name = [[NSProcessInfo processInfo] processName];
- /* Set up OS X app menu */
+ /* Set up macOS app menu */
NSTRACE_MSG ("Menu init");
@@ -5784,7 +5784,7 @@ not_in_argv (NSString *arg)
NSTRACE ("[EmacsView keyDown:]");
- /* Rhapsody and OS X give up and down events for the arrow keys */
+ /* Rhapsody and macOS give up and down events for the arrow keys */
if (ns_fake_keydown == YES)
ns_fake_keydown = NO;
@@ -7176,8 +7176,8 @@ not_in_argv (NSString *arg)
#if MAC_OS_X_VERSION_MAX_ALLOWED >= MAC_OS_X_VERSION_10_7
unsigned val = (unsigned)[NSApp presentationOptions];
- // OSX 10.7 bug fix, the menu won't appear without this.
- // val is non-zero on other OSX versions.
+ // Mac OS X 10.7 bug fix, the menu won't appear without this.
+ // val is non-zero on other macOS versions.
if (val == 0)
{
diff --git a/src/unexmacosx.c b/src/unexmacosx.c
index bdacc8b540b..f755f7fafd9 100644
--- a/src/unexmacosx.c
+++ b/src/unexmacosx.c
@@ -1,4 +1,4 @@
/* Dump Emacs in Mach-O format for use on Mac OS X.
Copyright (C) 2001-2016 Free Software Foundation, Inc.
This file is part of GNU Emacs.
@@ -24,7 +24,7 @@ along with GNU Emacs. If not, see <http://www.gnu.org/licenses/>. */
Mach-O format: the file loader.h, man pages for Mach-O and ld, old
NEXTSTEP documents of the Mach-O format. The tool otool dumps the
mach header (-h option) and the load commands (-l option) in a
- Mach-O file. The tool nm on Mac OS X displays the symbol table in
+ Mach-O file. The tool nm on macOS displays the symbol table in
a Mach-O file. For examples of unexec for the Mach-O format, see
the file unexnext.c in the GNU Emacs distribution, the file
unexdyld.c in the Darwin port of GNU Emacs 20.7, and unexdyld.c in
@@ -33,7 +33,7 @@ along with GNU Emacs. If not, see <http://www.gnu.org/licenses/>. */
Read that to see what they do. This file was written completely
from scratch, making use of information from the above sources. */
/* The Mac OS X implementation of unexec makes use of Darwin's `zone'
memory allocator. All calls to malloc, realloc, and free in Emacs
are redirected to unexec_malloc, unexec_realloc, and unexec_free in
this file. When temacs is run, all memory requests are handled in
@@ -49,7 +49,7 @@ along with GNU Emacs. If not, see <http://www.gnu.org/licenses/>. */
block must be obtained by malloc and the old contents copied to
it. */
-/* Peculiarity of the Mach-O files generated by ld in Mac OS X
+/* Peculiarity of the Mach-O files generated by ld in macOS
(possible causes of future bugs if changed).
The file offset of the start of the __TEXT segment is zero. Since
@@ -118,9 +118,9 @@ along with GNU Emacs. If not, see <http://www.gnu.org/licenses/>. */
#include <assert.h>
-/* LC_DATA_IN_CODE is not defined in mach-o/loader.h on OS X 10.7.
+/* LC_DATA_IN_CODE is not defined in mach-o/loader.h on Mac OS X 10.7.
But it is used if we build with "Command Line Tools for Xcode 4.5
- (OS X Lion) - September 2012". */
+ (Mac OS X Lion) - September 2012". */
#ifndef LC_DATA_IN_CODE
#define LC_DATA_IN_CODE 0x29 /* table of non-instructions in __text */
#endif
@@ -1,4 +1,4 @@
-/* Dump Emacs in Mach-O format for use on Mac OS X.
+/* Dump Emacs in Mach-O format for use on macOS.
Copyright (C) 2001-2016 Free Software Foundation, Inc.
This file is part of GNU Emacs.
@@ -33,7 +33,7 @@ along with GNU Emacs. If not, see <http://www.gnu.org/licenses/>. */
Read that to see what they do. This file was written completely
from scratch, making use of information from the above sources. */
-/* The Mac OS X implementation of unexec makes use of Darwin's `zone'
+/* The macOS implementation of unexec makes use of Darwin's `zone'
memory allocator. All calls to malloc, realloc, and free in Emacs
are redirected to unexec_malloc, unexec_realloc, and unexec_free in